import React, { ErrorInfo } from "react";

interface State {
    hasError: boolean;
}
interface Props {
    [key: string]: any;
}
class ErrorBoundary extends React.Component<Props, State> {
    constructor(props: Props) {
        super(props);
        this.state = {
            hasError: false
        };
    }

    static getDerivedStateFromError() {
        // Update state so the next render will show the fallback UI.
        return {
            hasError: true
        };
    }

    public override componentDidCatch(error: Error, errorInfo: ErrorInfo) {
        console.log("An error occurred while rendering a page element:");
        console.log(error, errorInfo);
    }

    public override render() {
        if (this.state.hasError) {
            // You can render any custom fallback UI
            return <h1>Something went wrong.</h1>;
        }

        return this.props.children;
    }
}

export default ErrorBoundary;
